@@ -3,11 +3,11 @@ library(httr)
 context("National Hydrography Dataset tests")
 
 test_that("The NHD Subregion boundaries dataset is availableat the correct URL", {
-  url <- 'ftp://ftp.igsb.uiowa.edu/gis_library/USA/huc_04.zip'
+  url <- "https://github.com/ropensci/FedData/raw/master/data-raw/nhd_huc4.gpkg.zip"
   expect_false(suppressWarnings(httr::http_error(url)))
   
-  url <- 'ftp://ftp.igsb.uiowa.edu/gis_library/USA/blah.zip'
-  expect_error(suppressWarnings(httr::http_error(url)))
+  url <- "https://github.com/ropensci/FedData/raw/master/data-raw/blah.zip"
+  expect_true(suppressWarnings(httr::http_error(url)))
 })
 
 test_that("The NHD staged subregions are available at the correct URL", {
